<?php
/**
 * Nari functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Nari
 */

define( 'NARI_VERSION', '1.0.12' );
define( 'NARI_SLUG', 'nari' );
define( 'NARI_DIR', rtrim( get_template_directory(), '/' ) );
define( 'NARI_URL', rtrim( get_template_directory_uri(), '/' ) );
define( 'NARI_UPGRADE_URL', 'https://checkout.freemius.com/mode/dialog/theme/11131/plan/18899/' );

// Include autoload.
if ( file_exists( NARI_DIR . '/vendor/autoload.php' ) ) {
	require_once NARI_DIR . '/vendor/autoload.php';
	require_once NARI_DIR . '/vendor/wptt/webfont-loader/wptt-webfont-loader.php';
	require_once NARI_DIR . '/vendor/ernilambar/ns-customizer-utilities/init.php';
	require_once NARI_DIR . '/vendor/ernilambar/wp-welcome/init.php';
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function nari_setup() {
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );
	add_image_size('nari-thumb', 730, 486, true);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'nari' ),
			'footer-menu' => esc_html__( 'Footer Menu', 'nari' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'nari_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );

	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );

	// Add support for responsive embedded content.
	add_theme_support( 'responsive-embeds' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action( 'after_setup_theme', 'nari_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function nari_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'nari_content_width', 640 );
}
add_action( 'after_setup_theme', 'nari_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function nari_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'nari' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'nari' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	for ( $i = 1; $i <= 3; $i ++ ) {
		register_sidebar( array(
			/* translators: 1: Widget number. */
			'name'          => sprintf( esc_html__( 'Footer %d', 'nari' ), $i ),
			'id'            => 'footer-' . $i,
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}
}
add_action( 'widgets_init', 'nari_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function nari_scripts() {
	wp_enqueue_style( 'nari-google-fonts', wptt_get_webfont_url( 'https://fonts.googleapis.com/css?family=Oxygen:400,700' ), '', NARI_VERSION );

	wp_enqueue_style( 'nari-style', get_stylesheet_uri(), array(), NARI_VERSION );

	wp_enqueue_script( 'nari-navigation', get_template_directory_uri() . '/js/navigation.js', array(), NARI_VERSION, true );

	wp_enqueue_script( 'nari-custom', get_template_directory_uri() . '/js/custom.js', array(), NARI_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'nari_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/customizer/core.php';

/**
 * Load Dynamic CSS.
 */
require get_template_directory() . '/inc/dynamic-css.php';

/**
 * Welcome page.
 */
require get_template_directory() . '/inc/welcome.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}
