<?php
/**
 * Featured Posts Options.
 *
 * @package Nari
 */

use Nilambar\CustomizerUtils\Control\DropdownTaxonomies;
use Nilambar\CustomizerUtils\Control\Switcher;
use Nilambar\CustomizerUtils\Control\Text;
use Nilambar\CustomizerUtils\Helper\Callback;
use Nilambar\CustomizerUtils\Helper\Sanitize;

// Featured Posts Section.
$wp_customize->add_section( 'section_featured_posts',
	array(
		'title'      => esc_html__( 'Featured Posts', 'nari' ),
		'priority'   => 100,
		'panel'      => 'theme_option_panel',
	)
);

// Setting enable_featured_posts.
$wp_customize->add_setting( 'theme_options[enable_featured_posts]',
	array(
		'default'           => $default['enable_featured_posts'],
		'sanitize_callback' => array( Sanitize::class, 'checkbox' ),
	)
);
$wp_customize->add_control(
	new Switcher(
		$wp_customize,
		'theme_options[enable_featured_posts]',
		array(
			'label'    => esc_html__( 'Enable Featured Posts', 'nari' ),
			'section'  => 'section_featured_posts',
			'priority' => 100,
		)
	)
);

// Setting featured_posts_heading.
$wp_customize->add_setting( 'theme_options[featured_posts_heading]',
	array(
		'default'           => $default['featured_posts_heading'],
		'sanitize_callback' => array( Sanitize::class, 'text' ),
	)
);
$wp_customize->add_control(
	new Text(
		$wp_customize,
		'theme_options[featured_posts_heading]',
		array(
			'label'    => esc_html__( 'Heading', 'nari' ),
			'section'  => 'section_featured_posts',
			'priority' => 100,
			'active_callback'   => array( Callback::class, 'active' ),
			'conditional_logic' => array(
				array(
					array(
						'key'     => 'theme_options[enable_featured_posts]',
						'compare' => '==',
						'value'   => true,
					),
				),
			),
		)
	)
);

// Setting featured_posts_category.
$wp_customize->add_setting( 'theme_options[featured_posts_category]',
	array(
		'default'           => $default['featured_posts_category'],
		'sanitize_callback' => array( Sanitize::class, 'select' ),
	)
);
$wp_customize->add_control(
	new DropdownTaxonomies(
		$wp_customize,
		'theme_options[featured_posts_category]',
		array(
			'label'    => esc_html__( 'Select Category', 'nari' ),
			'section'  => 'section_featured_posts',
			'priority' => 100,
			'active_callback'   => array( Callback::class, 'active' ),
			'conditional_logic' => array(
				array(
					array(
						'key'     => 'theme_options[enable_featured_posts]',
						'compare' => '==',
						'value'   => true,
					),
				),
			),
		)
	)
);
