<?php
/**
 * Welcome
 *
 * @package Nari
 */

use Nilambar\Welcome\Welcome;

add_action(
	'wp_welcome_init',
	function() {
		$obj = new Welcome( 'theme', 'nari' );

		$obj->set_page(
			array(
				'menu_title'  => esc_html__( 'About Nari', 'nari' ),
				'menu_slug'   => 'about-nari',
				'parent_page' => 'themes.php',
			)
		);

		$obj->set_admin_notice(
			array(
				'screens' => array( 'themes', 'dashboard' ),
			)
		);

		$obj->set_quick_links(
			array(
				array(
					'text' => esc_html__( 'View Demos', 'nari' ),
					'url'  => 'https://dandure.com/nari/',
					'type' => 'primary',
				),
				array(
					'text' => esc_html__( 'Theme Homepage', 'nari' ),
					'url'  => 'https://wphait.com/themes/nari/',
					'type' => 'secondary',
				),
			)
		);

		$obj->add_tab(
			array(
				'id'    => 'getting-started',
				'title' => esc_html__( 'Getting Started', 'nari' ),
				'type'  => 'grid',
				'items' => array(
					array(
						'title'       => esc_html__( 'Customize Everything', 'nari' ),
						'icon'        => 'dashicons dashicons-admin-customizer',
						'description' => esc_html__( 'Theme uses Customizer API for theme options. Start customizing every aspect of the website with customizer.', 'nari' ),
						'button_text' => esc_html__( 'Go to Customizer', 'nari' ),
						'button_url'  => wp_customize_url(),
						'button_type' => 'primary',
					),
					array(
						'title'       => esc_html__( 'Get Support', 'nari' ),
						'icon'        => 'dashicons dashicons-editor-help',
						'description' => esc_html__( 'Got theme support question or found bug or got some feedbacks? Please visit support forum in the WordPress.org directory.', 'nari' ),
						'button_text' => esc_html__( 'Visit Support', 'nari' ),
						'button_url'  => 'https://wordpress.org/support/theme/nari/#new-post',
						'button_type' => 'secondary',
						'is_new_tab'  => true,
					),
					array(
						'title'       => esc_html__( 'Documentation', 'nari' ),
						'icon'        => 'dashicons dashicons-admin-page',
						'description' => 'Kindly check our theme documentation for detailed information and instructions.',
						'button_text' => esc_html__( 'View Documentation', 'nari' ),
						'button_url'  => 'https://dandure.com/documentation/nari/',
						'button_type' => 'secondary',
						'is_new_tab'  => true,
					),
					array(
						'title'       => esc_html__( 'Child Theme', 'nari' ),
						'icon'        => 'dashicons dashicons-admin-appearance',
						'description' => 'Want to customize theme file? Please use a child theme.',
						'button_text' => esc_html__( 'About Child Theme', 'nari' ),
						'button_url'  => 'https://developer.wordpress.org/themes/advanced-topics/child-themes/',
						'button_type' => 'secondary',
						'is_new_tab'  => true,
					),
				),
			)
		);

		$obj->add_tab(
			array(
				'id'             => 'free-vs-pro',
				'title'          => 'Free Vs. Pro',
				'type'           => 'comparison',
				'upgrade_button' => array(
					'url' => NARI_UPGRADE_URL,
				),
				'items'          => array(
					array(
						'title' => 'Show / Hide Site Title',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Show / Hide Site Tagline',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Logo Height Option',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Full Width Banner',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Featured Posts on Home Page',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title'       => 'Breadcrumb',
						'description' => 'Rank Math or Yoast SEO',
						'free'        => 'yes',
						'pro'         => 'yes',
					),
					array(
						'title'       => 'Post Meta Options',
						'description' => 'Drag and drop and enable/disable',
						'free'        => 'yes',
						'pro'         => 'yes',
					),
					array(
						'title' => 'Social Share',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Related Posts',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'WooCommerce Support',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Page Speed Optimized',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Search Engine Optimized',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title'       => 'Page Builder Compatibility',
						'description' => 'Compatible with page builders like Elementor',
						'free'        => 'yes',
						'pro'         => 'yes',
					),
					array(
						'title' => 'Google Core Web Vitals Optimized',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'No jQuery',
						'free'  => 'yes',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Dark Skin',
						'free'  => 'no',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Sticky Navigation',
						'free'  => 'no',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Color and Typography',
						'free'  => 'no',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Blog Layouts',
						'free'  => '1',
						'pro'   => '5',
					),
					array(
						'title' => 'Sticky Sidebar',
						'free'  => 'no',
						'pro'   => 'yes',
					),
					array(
						'title'       => 'Sidebar Options',
						'description' => 'Left, Right and No Sidebar',
						'free'        => 'no',
						'pro'         => 'yes',
					),
					array(
						'title'       => 'Social Share Position',
						'description' => 'Sticky / Regular',
						'free'        => 'no',
						'pro'         => 'yes',
					),
					array(
						'title' => 'Customize Powered By Text',
						'free'  => 'no',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Author Box',
						'free'  => 'no',
						'pro'   => 'yes',
					),
					array(
						'title' => 'Theme Support',
						'free'  => 'Forum',
						'pro'   => 'Dedicated / Forum',
					),
				),
			)
		);

		$obj->add_tab(
			array(
				'id'    => 'plugins',
				'title' => esc_html__( 'Recommended Plugins', 'nari' ),
				'type'  => 'plugin',
				'items' => array(
					array(
						'name'        => esc_html__( 'Coming Soon & Maintenance Mode Page', 'nari' ),
						'description' => esc_html__( 'Simple and easy to setup Coming soon, Under Construction and Maintenance page plugin.', 'nari' ),
						'slug'        => 'nifty-coming-soon-and-under-construction-page',
					),
					array(
						'name'        => esc_html__( 'Post Grid Elementor Addon', 'nari' ),
						'description' => esc_html__( 'Elementor page builder addon to display posts in a grid.', 'nari' ),
						'slug'        => 'post-grid-elementor-addon',
					),
				),
			)
		);

		$obj->set_sidebar(
			array(
				'render_callback' => 'nari_render_welcome_page_sidebar',
			)
		);

		$obj->run();
	}
);

/**
 * Render welcome page sidebar.
 *
 * @since 1.0.0
 *
 * @param Welcome $object Instance of Welcome class.
 */
function nari_render_welcome_page_sidebar( $object ) {
	$object->render_sidebar_box(
		array(
			'title'        => esc_html__( 'Upgrade to Pro', 'nari' ),
			'content'      => esc_html__( 'Upgrade to pro version for additional features and options.', 'nari' ),
			'class'        => 'gray',
			'button_text'  => esc_html__( 'Upgrade Now', 'nari' ),
			'button_url'   => NARI_UPGRADE_URL,
			'button_class' => 'button button-primary button-upgrade',
		),
		$object
	);

	$object->render_sidebar_box(
		array(
			'title'        => esc_html__( 'Leave a Review', 'nari' ),
			'content'      => $object->get_stars() . sprintf( esc_html__( 'Are you are enjoying %1$s? We would appreciate a review.', 'nari' ), $object->get_name() ),
			'button_text'  => esc_html__( 'Submit Review', 'nari' ),
			'button_url'   => 'https://wordpress.org/support/theme/nari/reviews/#new-post',
			'button_class' => 'button',
		),
		$object
	);

	$object->render_sidebar_box(
		array(
			'title'   => esc_html__( 'Our Themes', 'nari' ),
			'content' => '<ol>
			<li><a href="https://wphait.com/themes/hello-blog/" target="_blank">Hello Blog - Elegant WordPress Blog theme</a></li>
			<li><a href="https://wphait.com/themes/pure-blog/" target="_blank">Pure Blog - Stylish WordPress Blog theme</a></li>
			<li><a href="https://wphait.com/themes/blog-up/" target="_blank">Blog Up - Clean WordPress Blog theme</a></li>
			<li><a href="https://wphait.com/themes/nari/" target="_blank">Nari - Feminine WordPress Blog Theme</a></li>
			<li><a href="https://wphait.com/themes/dhor/" target="_blank">Dhor - Minimal WordPress Blog Theme</a></li>
			</ol>',
		),
		$object
	);
}
